@@ -1,4 +1,5 @@
-use std::cell::RefCell;
+use crate::util::base54::incr_base54;
+use rayon::prelude::*;
 use swc_atoms::{js_word, JsWord};
 use swc_common::{
     collections::{AHashMap, AHashSet},
@@ -6,8 +7,6 @@ use swc_common::{
 };
 use swc_ecma_utils::Id;
 
-use crate::util::base54::incr_base54;
-
 #[derive(Debug, Default)]
 pub(crate) struct Scope {
     pub data: ScopeData,
@@ -17,12 +16,12 @@ pub(crate) struct Scope {
 
 #[derive(Debug, Default)]
 pub struct ScopeData {
-    decls: RefCell<AHashSet<Id>>,
+    decls: AHashSet<Id>,
 
     /// Usages in current scope.
-    usages: RefCell<AHashSet<Id>>,
+    usages: AHashSet<Id>,
 
-    queue: RefCell<Vec<Id>>,
+    queue: Vec<Id>,
 }
 
 impl Scope {
@@ -31,11 +30,10 @@ impl Scope {
             return;
         }
 
-        self.data.decls.get_mut().insert(id.clone());
+        self.data.decls.insert(id.clone());
         {
-            let b = self.data.queue.get_mut();
-            if !b.contains(id) {
-                b.push(id.clone());
+            if !self.data.queue.contains(id) {
+                self.data.queue.push(id.clone());
             }
         }
     }
@@ -45,7 +43,7 @@ impl Scope {
             return;
         }
 
-        self.data.usages.get_mut().insert(id.clone());
+        self.data.usages.insert(id.clone());
     }
 
     pub(super) fn rename(
@@ -55,7 +53,7 @@ impl Scope {
         preserved_symbols: &AHashSet<JsWord>,
     ) {
         let mut n = 0;
-        for id in self.data.queue.get_mut().take() {
+        for id in self.data.queue.take() {
             if preserved.contains(&id) {
                 continue;
             }
@@ -82,30 +80,62 @@ impl Scope {
     }
 
     fn can_rename(&self, id: &Id, symbol: &JsWord, renamed: &AHashMap<Id, JsWord>) -> bool {
-        for used_id in self
-            .data
-            .usages
-            .borrow()
-            .iter()
-            .chain(self.data.decls.borrow().iter())
+        if cfg!(target_arch = "wasm32")
+            || self
+                .data
+                .usages
+                .iter()
+                .chain(self.data.decls.iter())
+                .count()
+                <= 64
         {
-            if *used_id == *id {
-                continue;
-            }
+            for used_id in self.data.usages.iter().chain(self.data.decls.iter()) {
+                if *used_id == *id {
+                    continue;
+                }
 
-            if let Some(renamed_id) = renamed.get(used_id) {
-                if renamed_id == symbol {
-                    return false;
+                if let Some(renamed_id) = renamed.get(used_id) {
+                    if renamed_id == symbol {
+                        return false;
+                    }
                 }
             }
-        }
+        } else {
+            if self
+                .data
+                .usages
+                .par_iter()
+                .chain(self.data.decls.par_iter())
+                .any(|used_id| {
+                    if *used_id == *id {
+                        return false;
+                    }
 
-        for c in self.children.iter() {
-            if !c.can_rename(id, symbol, renamed) {
+                    if let Some(renamed_id) = renamed.get(used_id) {
+                        if renamed_id == symbol {
+                            return true;
+                        }
+                    }
+
+                    false
+                })
+            {
                 return false;
             }
         }
 
-        true
+        if cfg!(target_arch = "wasm32") {
+            for c in self.children.iter() {
+                if !c.can_rename(id, symbol, renamed) {
+                    return false;
+                }
+            }
+
+            true
+        } else {
+            self.children
+                .par_iter()
+                .all(|c| c.can_rename(id, symbol, renamed))
+        }
     }
 }
